@@ -509,7 +509,7 @@ QRectF KStandardItemListWidget::selectionRect() const
         QRectF adjustedIconRect = iconRect().adjusted(-padding, -padding, padding, padding);
         QRectF result = adjustedIconRect | m_textRect;
         if (m_highlightEntireRow) {
-            result.setRight(m_columnWidthSum + leadingPadding());
+            result.setRight(m_columnWidthSum + sidePadding());
         }
         return result;
     }
@@ -727,7 +727,7 @@ void KStandardItemListWidget::columnWidthChanged(const QByteArray& role,
     m_dirtyLayout = true;
 }
 
-void KStandardItemListWidget::leadingPaddingChanged(qreal padding) {
+void KStandardItemListWidget::sidePaddingChanged(qreal padding) {
     Q_UNUSED(padding)
     m_dirtyLayout = true;
 }
@@ -957,7 +957,7 @@ void KStandardItemListWidget::updateExpansionArea()
             const qreal inc = (widgetHeight - widgetIconSize) / 2;
             const qreal x = expandedParentsCount * widgetHeight + inc;
             const qreal y = inc;
-            const qreal xPadding = m_highlightEntireRow ? leadingPadding() : 0;
+            const qreal xPadding = m_highlightEntireRow ? sidePadding() : 0;
             m_expansionArea = QRectF(xPadding + x, y, widgetIconSize, widgetIconSize);
             return;
         }
@@ -1104,7 +1104,16 @@ void KStandardItemListWidget::updatePixmapCache()
 
     }
 
-    m_iconRect = QRectF(m_pixmapPos, QSizeF(m_scaledPixmapSize));
+    if (m_layout == IconsLayout) {
+        m_iconRect = QRectF(m_pixmapPos, QSizeF(m_scaledPixmapSize));
+    } else {
+        const qreal widthOffset = widgetIconSize - m_scaledPixmapSize.width();
+        const qreal heightOffset = widgetIconSize - m_scaledPixmapSize.height();
+        const QPointF squareIconPos(m_pixmapPos.x() - 0.5 * widthOffset,
+                                    m_pixmapPos.y() - 0.5 * heightOffset);
+        const QSizeF squareIconSize(widgetIconSize, widgetIconSize);
+        m_iconRect = QRectF(squareIconPos, squareIconSize);
+    }
 
     // Prepare the pixmap that is used when the item gets hovered
     if (isHovered()) {
@@ -1196,7 +1205,11 @@ QString KStandardItemListWidget::elideRightKeepExtension(const QString &text, in
             QString ret = m_customizedFontMetrics.elidedText(text.chopped(extensionLength),
                                                              Qt::ElideRight,
                                                              elidingWidth - extensionWidth);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             ret.append(text.rightRef(extensionLength));
+#else
+            ret.append(QStringView(text).right(extensionLength));
+#endif
             return ret;
         }
     }
@@ -1393,7 +1406,7 @@ void KStandardItemListWidget::updateDetailsLayoutTextCache()
     if (m_supportsItemExpanding) {
         firstColumnInc += (m_expansionArea.left() + m_expansionArea.right() + widgetHeight) / 2;
     } else {
-        firstColumnInc += option.padding + leadingPadding();
+        firstColumnInc += option.padding + sidePadding();
     }
 
     qreal x = firstColumnInc;
@@ -1409,7 +1422,7 @@ void KStandardItemListWidget::updateDetailsLayoutTextCache()
 
         const bool isTextRole = (role == "text");
         if (isTextRole) {
-            availableTextWidth -= firstColumnInc - leadingPadding();
+            availableTextWidth -= firstColumnInc - sidePadding();
         }
 
         if (requiredWidth > availableTextWidth) {
@@ -1431,7 +1444,7 @@ void KStandardItemListWidget::updateDetailsLayoutTextCache()
 
             // The column after the name should always be aligned on the same x-position independent
             // from the expansion-level shown in the name column
-            x -= firstColumnInc - leadingPadding();
+            x -= firstColumnInc - sidePadding();
         } else if (isRoleRightAligned(role)) {
             textInfo->pos.rx() += roleWidth - requiredWidth - columnWidthInc;
         }
